---
hide-toc: true
---

<!-- [![codecov](https://codecov.io/gh/saifkhichi96/pocket-pose/branch/latest/graph/badge.svg)](https://codecov.io/gh/saifkhichi96/pocket-pose) -->
[![build](https://github.com/saifkhichi96/pocket-pose/actions/workflows/build.yml/badge.svg)](https://github.com/saifkhichi96/pocket-pose/actions/workflows/build.yml)
[![PyPI](https://img.shields.io/pypi/v/pocket-pose)](https://pypi.org/project/pocket-pose/)
[![LICENSE](https://img.shields.io/github/license/saifkhichi96/pocket-pose.svg)](https://github.com/saifkhichi96/pocket-pose/blob/main/LICENSE)
[![Average time to resolve an issue](https://isitmaintained.com/badge/resolution/saifkhichi96/pocket-pose.svg)](https://github.com/saifkhichi96/pocket-pose/issues)
[![Percentage of issues still open](https://isitmaintained.com/badge/open/saifkhichi96/pocket-pose.svg)](https://github.com/saifkhichi96/pocket-pose/issues)

[🛠️Installation](installation.md) |
[👀Model Zoo](https://pocketpose.com/model-zoo/) |
[🆕Update News](https://github.com/saifkhichi96/pocket-pose/blob/main/CHANGELOG.md) |
[🤔Reporting Issues](https://github.com/saifkhichi96/pocket-pose/issues/new/choose) |

# PocketPose Documentation

Welcome to the documentation for PocketPose, an open-source framework designed for real-time pose estimation on consumer devices, such as smartphones, tablets, and laptops. For more information, please visit [the project website](https://pocketpose.com).

## Table of Contents

```{toctree}
:hidden:
:caption: Get Started

installation.md
contributing.md
faq.md
```

```{toctree}
:caption: User Guides

user_guides/inference.md
user_guides/model_analysis.md
user_guides/how_to_deploy.md
```

```{toctree}
:hidden:
:caption: Advanced Guides

advanced_guides/dataflow.md
advanced_guides/implement_new_models.md
advanced_guides/decoders.md
advanced_guides/customize_datasets.md
```

```{toctree}
:caption: Model Zoo

model_zoo.md
model_zoo/body_2d_keypoint.md
model_zoo/body_3d_keypoint.md
model_zoo/face_2d_keypoint.md
model_zoo/hand_2d_keypoint.md
model_zoo/wholebody_2d_keypoint.md
model_zoo/animal_2d_keypoint.md
```

```{toctree}
:caption: Dataset Zoo

dataset_zoo.md
dataset_zoo/2d_body_keypoint.md
dataset_zoo/2d_face_keypoint.md
dataset_zoo/2d_hand_keypoint.md
```

```{toctree}
:caption: API Reference

```